@@ -1,6 +1,6 @@
 from formskit.tests.base import FormskitTestCase
 from formskit.field import Field
-from formskit.field_convert import ToInt
+from formskit.converters import ToInt
 
 
 class TestFakeConvert(FormskitTestCase):
@@ -31,7 +31,17 @@ class TestToInt(FormskitTestCase):
         assert self.field.values[0].value == '12'
         assert self.field.get_value() == 12
 
+    def test_convert_fail(self):
+        self.field.set_values([''])
+        assert self.field.values[0].value == ''
+        assert self.field.get_value() is None
+
     def test_convert_back(self):
         self.field.set_value(12)
         assert self.field.values[0].value == '12'
         assert self.field.get_value() == 12
+
+    def test_convert_back_fail(self):
+        self.field.set_value(None)
+        assert self.field.values[0].value is None
+        assert self.field.get_value() is None
