@@ -5,22 +5,30 @@ from pytest import raises
 from formskit.tests.base import FormskitTestCase
 from formskit import Field
 from formskit.validators import NotEmpty, IsDigit
-from formskit.form import Form, TreeForm
+from formskit.form import Form
+from formskit.tree_form import TreeForm
 from formskit.field import FieldValue
+from formskit.translation import Translation
+
+
+class ExampleField(Field):
+
+    def _get_message_object(self):
+        return Translation()
 
 
 class FieldTest(FormskitTestCase):
 
     def test_init_form(self):
         form = 123
-        field = Field(None, None, None)
+        field = ExampleField(None, None, None)
         field.init_form(form)
 
         self.assertEqual(form, field.form)
 
     def test_validate(self):
         not_empty = NotEmpty()
-        field = Field('name', [not_empty])
+        field = ExampleField('name', [not_empty])
 
         self.assertEqual(False, field.validate())
         self.assertEqual(field, not_empty.field)
@@ -31,7 +39,7 @@ class FieldTest(FormskitTestCase):
         self.assertEqual(True, field.validate())
 
     def test_two_validators(self):
-        field = Field('name', [NotEmpty(), IsDigit()])
+        field = ExampleField('name', [NotEmpty(), IsDigit()])
 
         field.validate()
         self.assertEqual(False, field.validate())
@@ -47,7 +55,7 @@ class FieldTest(FormskitTestCase):
         self.assertEqual(True, field.validate())
 
     def test_set_values(self):
-        field = Field('name')
+        field = ExampleField('name')
 
         field.set_values(['value'])
 
@@ -55,14 +63,14 @@ class FieldTest(FormskitTestCase):
         assert 'value' == field_value.value
 
     def test_set_values_on_ignore(self):
-        field = Field('name', ignore=True)
+        field = ExampleField('name', ignore=True)
 
         field.set_values(['value'])
 
         assert 0 == len(field.values)
 
     def test_reset(self):
-        field = Field('name')
+        field = ExampleField('name')
         field.set_values(['val'])
         field.messages = ['msg']
         field.error = True
@@ -73,8 +81,20 @@ class FieldTest(FormskitTestCase):
         assert field.messages == []
         assert field.error is False
 
+    def test_reset_on_ignore(self):
+        field = ExampleField('name', ignore=True)
+        field.set_values(['val'], True)
+        field.messages = ['msg']
+        field.error = True
+
+        field.reset()
+
+        assert field.values[0].value == 'val'
+        assert field.messages == ['msg']
+        assert field.error is True
+
     def test_set_error(self):
-        field = Field('name')
+        field = ExampleField('name')
 
         field.set_error('msg')
 
@@ -155,17 +175,17 @@ class GetValueErrorTests(FormskitTestCase):
 
     def setUp(self):
         super().setUp()
-        self.field = Field('name')
+        self.field = ExampleField('name')
 
     def test_index_error(self):
         with raises(IndexError):
-            self.field.get_value_error()
+            self.field.get_value_errors()
 
     def test_defaul(self):
-        assert self.field.get_value_error(default='elf') == 'elf'
+        assert self.field.get_value_errors(default='elf') == 'elf'
 
     def test_normal(self):
         self.field.values.append(FieldValue(self.field, 'val'))
-        self.field.values[0].message = 'my error'
+        self.field.values[0].messages = [(lambda: 'my error')]
 
-        assert self.field.get_value_error() == 'my error'
+        assert self.field.get_value_errors() == ['my error']
