@@ -4,9 +4,11 @@ from decimal import Decimal, InvalidOperation
 
 
 class FieldValidator(object):
+    message = None
 
     def __init__(self):
-        self.message = self.__class__.__name__
+        if self.message is None:
+            self.message = self.__class__.__name__
 
     def init_field(self, field):
         self.field = field
@@ -33,6 +35,8 @@ class FieldValidator(object):
 
 class NotEmpty(FieldValidator):
 
+    """Will fail if no value found of value is empty or has only whitespaces"""
+
     def validate_field(self):
         return len(self.field.values) > 0
 
@@ -50,14 +54,20 @@ class NotEmpty(FieldValidator):
 
 class IsDigit(FieldValidator):
 
+    """Will fail if value is not a digit."""
+
     regex = re.compile('^-{0,1}[0-9]+$')
 
     def validate_value(self):
+        if not self.value:
+            return True
         return re.search(self.regex, self.value) is not None
 
 
 class IsDecimal(FieldValidator):
 
+    """Will fail if value can not be converted to decimal.Decimal."""
+
     def validate_value(self):
         try:
             Decimal(self.value)
@@ -66,7 +76,9 @@ class IsDecimal(FieldValidator):
             return False
 
 
-class Email(FieldValidator):
+class IsEmail(FieldValidator):
+
+    """Will fail if value is not an email."""
 
     regex = re.compile(
         "^.+\\@(\\[?)[a-zA-Z0-9\\-\\.]+\\.([a-zA-Z]{2,3}|[0-9]{1,3})(\\]?)$")
@@ -79,6 +91,8 @@ class Email(FieldValidator):
 
 class InList(FieldValidator):
 
+    """Will fail if value is not in list."""
+
     def __init__(self, values, message=None):
         super().__init__()
         self.values = values
